function stencil = getsten(x, y, h);
%----------------------------------------------------------------------------
%
% For the linear PDE
%     a*u_xx + b*u_yy + c*u_x + d*u_y + e*u = f
% on the unit square, where all of a - f are functions of (x,y), give
% the values for the 5-point centered difference stencil oriented as:
%
%
%                           st(up)
%                            |
%                            |  
%                            |
%                            |
%                            |
%                            | 
%    st(left)------------- st(center) ------------ st(right)
%                            |
%                            |
%                            |
%                            |
%                            |
%                            |
%                         st(down)
%
%
% st(rhs) is the right hand side vector component from source terms. I've
% used "st" instead of "stencil" to make the diagram not extend too far.
% In class, those stencil values were labeled as alpha_1, ... alpha_6.
%
% The indexing is made less opaque by using the directions instead of the
% numbers 1-6. This basically defines a row of the the sparse matrix resulting
% from the discretization, with 
%
%   center ~ u(x,y)
%   left   ~ u(x-h,y)
%   down   ~ u(x,y-h)
%   right  ~ u(x+h,y)
%   up     ~ u(x,y+h)
%
% So the corresponding equation is
%       stencil(center) * u(x,y)
%     + stencil(left)   * u(x-h,y)
%     + stencil(right)  * u(x+h,y)
%     + stencil(down)   * u(x,y-h)
%     + stencil(up)     * u(x,y+h)
%     =  stencil(rhs)
%
% This is for the domain [0,N+1] x [0,N+1] with mesh spacing h = 1/(N+1),
% and the functions afun-ffun are presumed to be on [0,1]x[0,1].
%
% Do not call this with x = 0 or 1, or y = 0 or 1. This should only be used  
% for point inside the domain, so that x-h, x+h, y-h, and y+h are all within
% the interval [0,1].
%----------------------------------------------------------------------------


    [center,left,down,right,up,rhs] = directions();

     a = afun(x,y);
     b = bfun(x,y);
     c = cfun(x,y);
     d = dfun(x,y);
     e = efun(x,y);
     f = ffun(x,y);

     stencil(center) =  2.0*(a + b) - e*h*h;
     stencil(left)   =  (c*h/2 - a);
     stencil(down)   =  (d*h/2 - b);
     stencil(right)  = -(c*h/2 + a);
     stencil(up)     = -(d*h/2 + b);
     stencil(rhs)    = -h*h*f;

